@@ -80,7 +80,8 @@ SH_backup_get (struct MHD_Connection *connection,
       resp = MHD_create_response_from_buffer (0,
                                               NULL,
                                               MHD_RESPMEM_PERSISTENT);
-      TALER_MHD_add_global_headers (resp);
+      TALER_MHD_add_global_headers (resp,
+                                    false);
       ret = MHD_queue_response (connection,
                                 MHD_HTTP_NO_CONTENT,
                                 resp);
@@ -121,7 +122,8 @@ SH_backup_get (struct MHD_Connection *connection,
           resp = MHD_create_response_from_buffer (0,
                                                   NULL,
                                                   MHD_RESPMEM_PERSISTENT);
-          TALER_MHD_add_global_headers (resp);
+          TALER_MHD_add_global_headers (resp,
+                                        false);
           ret = MHD_queue_response (connection,
                                     MHD_HTTP_NOT_MODIFIED,
                                     resp);
@@ -219,7 +221,8 @@ SH_return_backup (struct MHD_Connection *connection,
   resp = MHD_create_response_from_buffer (backup_size,
                                           backup,
                                           MHD_RESPMEM_MUST_FREE);
-  TALER_MHD_add_global_headers (resp);
+  TALER_MHD_add_global_headers (resp,
+                                false);
   {
     char *sig_s;
     char *prev_s;
