@@ -233,7 +233,8 @@ make_payment_request (const char *order_id,
   resp = MHD_create_response_from_buffer (0,
                                           NULL,
                                           MHD_RESPMEM_PERSISTENT);
-  TALER_MHD_add_global_headers (resp);
+  TALER_MHD_add_global_headers (resp,
+                                false);
   {
     char *hdr;
     const char *pfx;
@@ -869,7 +870,8 @@ SH_backup_post (struct MHD_Connection *connection,
         resp = MHD_create_response_from_buffer (0,
                                                 NULL,
                                                 MHD_RESPMEM_PERSISTENT);
-        TALER_MHD_add_global_headers (resp);
+        TALER_MHD_add_global_headers (resp,
+                                      false);
         ret = MHD_queue_response (connection,
                                   MHD_HTTP_NOT_MODIFIED,
                                   resp);
@@ -1007,7 +1009,8 @@ SH_backup_post (struct MHD_Connection *connection,
       resp = MHD_create_response_from_buffer (0,
                                               NULL,
                                               MHD_RESPMEM_PERSISTENT);
-      TALER_MHD_add_global_headers (resp);
+      TALER_MHD_add_global_headers (resp,
+                                    false);
       ret = MHD_queue_response (connection,
                                 MHD_HTTP_NOT_MODIFIED,
                                 resp);
@@ -1025,7 +1028,8 @@ SH_backup_post (struct MHD_Connection *connection,
     resp = MHD_create_response_from_buffer (0,
                                             NULL,
                                             MHD_RESPMEM_PERSISTENT);
-    TALER_MHD_add_global_headers (resp);
+    TALER_MHD_add_global_headers (resp,
+                                  false);
     ret = MHD_queue_response (connection,
                               MHD_HTTP_NO_CONTENT,
                               resp);
