@@ -148,9 +148,9 @@ run (void *cls,
                                     NULL,
                                     true,
                                     true),
-    TALER_TESTING_cmd_merchant_post_instances ("instance-create-default",
+    TALER_TESTING_cmd_merchant_post_instances ("instance-create-admin",
                                                merchant_url,
-                                               "default",
+                                               "admin",
                                                MHD_HTTP_NO_CONTENT),
     TALER_TESTING_cmd_merchant_post_account (
       "instance-create-default-account",
